@@ -293,6 +293,11 @@ retry <- function(expr, envir = parent.frame(), retries = 5,
   }
 }
 
+#' @keywords internal
+isCI <- function() {
+  as.logical(Sys.getenv("CI"))
+}
+
 #' Test whether system is Windows
 #'
 #' This is used so that unit tests can override this using `testthat::with_mock`.
@@ -300,7 +305,11 @@ retry <- function(expr, envir = parent.frame(), retries = 5,
 isWindows <- function() identical(.Platform$OS.type, "windows")
 
 #' @keywords internal
-isMac <- function() identical(tolower(Sys.info()["sysname"]), "darwin")
+isMac <- function() {
+  Sys.info()[["sysname"]] |>
+    tolower() |>
+    identical("darwin")
+}
 
 #' Provide standard messaging for missing package dependencies
 #'
@@ -361,6 +370,37 @@ isDirectory <- function(pathnames) {
   id
 }
 
+isAbsolutePath <- function(pathnames) {
+  # modified slightly from R.utils::isAbsolutePath
+  keep <- is.character(pathnames)
+  if (isFALSE(keep)) stop("pathnames must be character")
+  nPathnames <- length(pathnames)
+  if (nPathnames == 0L)
+    return(logical(0L))
+  done <- logical(nPathnames)
+  nas <- is.na(pathnames)
+  if (all(nas)) return(!nas)
+
+  tildas <- startsWith(pathnames[!nas], "~")
+  if (any(tildas))
+    done[!nas][tildas] <- TRUE
+
+  if (all(tildas))
+    return(done)
+
+  colon <- regexpr("^.:(/|\\\\)", pathnames[!nas][!tildas])
+  hasColon <- colon != -1L
+  if (any(hasColon))
+    done[!nas][!tildas][hasColon] <- TRUE
+  if (all(hasColon))
+    return(done)
+  curPaths <- pathnames[!nas][!tildas][!hasColon]
+  done[!nas][!tildas][!hasColon] <- startsWith(curPaths, "/") | startsWith(curPaths, "\\")
+  names(done) <- pathnames
+  return(done)
+}
+
+
 isFile <- function(pathnames) {
   keep <- is.character(pathnames)
   if (isFALSE(keep)) stop("pathnames must be character")
@@ -527,7 +567,13 @@ methodFormals <- function(fun, signature = character(), envir = parent.frame())
 
 
 .fileExtsKnown <- function() {
-  shpFile <- getOption("reproducible.shapefileRead", "sf::st_read")
+  if (requireNamespace("sf", quietly = TRUE) && requireNamespace("DBI", quietly = TRUE))
+    shpFile <- getOption("reproducible.shapefileRead", "sf::st_read")
+  else {
+    shpFile <- "terra::vect"
+    if (identical(getOption("reproducible.shapefileRead"), "sf::st_read"))
+      options("reproducible.shapefileRead" = shpFile) # can't use sf::st_read
+  }
   griddedFile <- getOption("reproducible.rasterRead", "terra::rast")
   griddedFileSave <- ""
   shpFileSave <- ""
@@ -537,6 +583,7 @@ methodFormals <- function(fun, signature = character(), envir = parent.frame())
     griddedFileSave <- "terra::writeRaster"
   if (shpFile %in% "sf::st_read")
     shpFileSave <- "sf::st_write"
+
   if (shpFile %in% "terra::vect")
     shpFileSave <- "terra::writeVector"
 
@@ -544,8 +591,10 @@ methodFormals <- function(fun, signature = character(), envir = parent.frame())
     rbind(
       c("rds", "base::readRDS", "base::saveRDS", "binary"),
       c("qs", "qs::qread", "qs::qsave", "qs"),
-      cbind(c("asc", "grd", "tif"), griddedFile, griddedFileSave, rasterType()),
-      cbind(c("shp", "gdb"), shpFile, shpFileSave, vectorType())
+      cbind(c("asc", "grd", "tif"), griddedFile, griddedFileSave,
+            rasterType(rasterRead = griddedFile)),
+      cbind(c("shp", "gdb"), shpFile, shpFileSave,
+            vectorType(vectorRead = shpFile))
     )
   )
   colnames(df) <- c("extension", "fun", "saveFun", "type")
@@ -577,12 +626,17 @@ rasterRead <- function(...)
 rasterType <- function(nlayers = 1,
                        rasterRead = getOption("reproducible.rasterRead", "terra::rast")) {
   if (is.character(rasterRead)) {
-    rasterRead <- eval(parse(text = rasterRead))
+    rasterRead <- if (.requireNamespace("terra") || .requireNamespace("raster"))
+      eval(parse(text = rasterRead))
+    else
+      ""
   }
-  if (identical(rasterRead, terra::rast))
-    "SpatRaster"
-  else
-    if (nlayers == 1) "RasterLayer" else "RasterStack"
+  if (!is.character(rasterRead))
+    rasterRead <- if (identical(rasterRead, terra::rast))
+      "SpatRaster"
+    else
+      if (nlayers == 1) "RasterLayer" else "RasterStack"
+  rasterRead
 }
 
 
@@ -598,16 +652,21 @@ vectorType <- function(vectorRead = getOption("reproducible.shapefileRead", "sf:
       if (.requireNamespace("raster", stopOnFALSE = TRUE))
         needRasterPkg <- TRUE
     }
-    vectorRead <- eval(parse(text = vectorRead))
-  }
-  if (identical(vectorRead, terra::vect)) {
-    "SpatVector"
-  } else if (needRasterPkg) {
-    .requireNamespace("raster", stopOnFALSE = TRUE)
-    "SpatialPolygons"
-  }  else {
-    "sf"
+    vectorRead <- if (.requireNamespace("terra") || .requireNamespace("sf") || .requireNamespace("sp"))
+      eval(parse(text = vectorRead))
+    else
+      ""
   }
+  if (!is.character(vectorRead))
+    vectorRead <- if (identical(vectorRead, terra::vect)) {
+      "SpatVector"
+    } else if (needRasterPkg) {
+      .requireNamespace("raster", stopOnFALSE = TRUE)
+      "SpatialPolygons"
+    }  else {
+      "sf"
+    }
+  vectorRead
 }
 
 
