@@ -2,9 +2,9 @@ test_that("test file-backed raster caching", {
   skip_on_cran()
   testInitOut <- testInit("terra", tmpFileExt = c(".tif", ".grd"),
                           opts = list(reproducible.useMemoise = FALSE))
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  # on.exit({
+  #   testOnExit(testInitOut)
+  # }, add = TRUE)
 
   nOT <- Sys.time()
 
@@ -17,8 +17,8 @@ test_that("test file-backed raster caching", {
 
   a <- randomPolyToDisk(tmpfile[1])
   # confirm that the raster has the given tmp filename
-  expect_identical(strsplit(tmpfile[1], split = "[\\/]"),
-                   strsplit(Filenames(a), split = "[\\/]"))
+  expect_equivalent(strsplit(normPath(tmpfile[1]), split = "[\\/]"),
+                   strsplit(normPath(Filenames(a)), split = "[\\/]"))
 
   # Using mock interactive function
   # https://www.mango-solutions.com/blog/testing-without-the-internet-using-mock-functions
@@ -214,8 +214,8 @@ test_that("test file-backed raster caching", {
   # changed behaviour as of reproducible 1.2.0.9020 -- now Cache doesn't protect user from filename collisions if user makes them
   expect_true(unique(dirname(normPath(Filenames(bb)))) != normPath(file.path(tmpdir, "rasters")))
   expect_true(identical(basename(Filenames(bb, allowMultiple = FALSE)), basename(tmpfile[2])))
-  expect_true(identical(normPath(Filenames(bb, allowMultiple = FALSE)), tmpfile[2]))
-  expect_true(dirname(Filenames(bb1, allowMultiple = FALSE)) == dirname(tmpfile[2]))
+  expect_equivalent(normPath(Filenames(bb, allowMultiple = FALSE)), normPath(tmpfile[2]))
+  expect_equivalent(normPath(dirname(Filenames(bb1, allowMultiple = FALSE))), normPath(dirname(tmpfile[2])))
   expect_true(basename(Filenames(bb1, allowMultiple = FALSE)) == basename(tmpfile[2]))
   expect_true(dataType2(bb) == "INT1U")
   if (.requireNamespace("raster"))
@@ -486,6 +486,7 @@ test_that("test environments", {
 
 test_that("test asPath", {
   testInitOut <- testInit("terra", tmpFileExt = "pdf",
+                          verbose = TRUE,
                           opts = list("reproducible.useMemoise" = TRUE,
                                       "reproducible.showSimilar" = FALSE))
   unlink(dir(tmpdir, full.names = TRUE))
@@ -563,7 +564,8 @@ test_that("test quoted FUN in Cache", {
 })
 
 test_that("test Cache argument inheritance to inner functions", {
-  testInitOut <- testInit("terra", opts = list("reproducible.showSimilar" = FALSE,
+  testInitOut <- testInit("terra", verbose = TRUE,
+                          opts = list("reproducible.showSimilar" = FALSE,
                                                 "reproducible.useMemoise" = FALSE))
   on.exit({
     testOnExit(testInitOut)
@@ -706,11 +708,11 @@ test_that("test Cache argument inheritance to inner functions", {
 test_that("test future", {
   skip_on_cran()
   skip_on_ci()
-  skip_if_not_installed("future")
+  # skip_if_not_installed("future")
 
   .onLinux <- .Platform$OS.type == "unix" && unname(Sys.info()["sysname"]) == "Linux"
   if (.onLinux) {
-    testInitOut <- testInit("terra", verbose = TRUE, tmpFileExt = ".rds")
+    testInitOut <- testInit(c("terra", "future"), verbose = TRUE, tmpFileExt = ".rds")
     optsFuture <- options("future.supportsMulticore.unstable" = "quiet")
     on.exit({
       testOnExit(testInitOut)
@@ -744,12 +746,11 @@ test_that("test future", {
 })
 
 test_that("test mergeCache", {
-  testInitOut <- testInit("data.table")
+  testInitOut <- testInit("data.table", verbose = TRUE)
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
 
-  # aaaa <<- gggg <<- kkkk <<- 1
   a <- Cache(rnorm, 1, cachePath = tmpdir)
   b <- Cache(rnorm, 2, cachePath = tmpCache)
 
@@ -931,14 +932,12 @@ test_that("test mergeCache", {
 # })
 
 test_that("test useCache = 'overwrite'", {
-  testInitOut <- testInit()
+  testInitOut <- testInit(verbose = TRUE)
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
 
   a <- Cache(rnorm, 1, useCache = "overwrite", cachePath = tmpCache)
-  #aaaa <<- bbbb <<- cccc <<- dddd <<- eeee <<- ffff <<- gggg <<- 1
-  # ffff <<- 1
   mess <- capture_messages({
     b <- Cache(rnorm, 1, useCache = "overwrite", cachePath = tmpCache)
   })
@@ -948,7 +947,8 @@ test_that("test useCache = 'overwrite'", {
   clearCache(x = tmpCache, ask = FALSE)
 
   testOnExit(testInitOut)
-  testInitOut <- testInit(ask = FALSE, opts = list("reproducible.useCache" = "overwrite"))
+  testInitOut <- testInit(ask = FALSE,verbose = TRUE,
+                          opts = list("reproducible.useCache" = "overwrite"))
 
   a <- Cache(rnorm, 1, cachePath = tmpCache)
   mess <- capture_messages({
@@ -961,6 +961,7 @@ test_that("test useCache = 'overwrite'", {
 test_that("test rm large non-file-backed rasters", {
   ## This is a large object test!
   skip_on_cran()
+  skip_if_not_installed("qs")
 
   if (!is.null(getOption("reproducible.conn", NULL)))
     if (!grepl("SQLite", class(getOption("reproducible.conn", NULL))))
@@ -972,6 +973,7 @@ test_that("test rm large non-file-backed rasters", {
     testOnExit(testInitOut)
   }, add = TRUE)
 
+  skip_if_not_installed("qs")
   opts11 <- options("reproducible.cacheSpeed" = "fast",
                     "reproducible.cacheSaveFormat" = "qs")
   on.exit(options(opts11), add = TRUE)
@@ -987,7 +989,7 @@ test_that("test cc", {
   skip_on_cran()
   # skip_on_ci()
 
-  testInitOut <- testInit(ask = FALSE)
+  testInitOut <- testInit(ask = FALSE, verbose = TRUE)
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
@@ -1109,7 +1111,7 @@ test_that("test changing reproducible.cacheSaveFormat midstream", {
 })
 
 test_that("test file link with duplicate Cache", {
-  testInitOut <- testInit(opts = list("reproducible.useMemoise" = FALSE))
+  testInitOut <- testInit(verbose = TRUE, opts = list("reproducible.useMemoise" = FALSE))
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
@@ -1221,7 +1223,7 @@ test_that("test .object arg for list in Cache", {
 
 test_that("quick arg in Cache as character", {
   skip_on_cran()
-  testInitOut <- testInit("terra", tmpFileExt = c("rds", "tif"))
+  testInitOut <- testInit("terra", verbose = TRUE, tmpFileExt = c("rds", "tif"))
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
@@ -1521,7 +1523,7 @@ test_that("test cache with new approach to match.call", {
   }
 
   # This tries to do a method that is not actually exported from a package; the generic (sf::st_make_valid) is
-  if (requireNamespace("sf")) {
+  if (.requireNamespace("sf")) {
     clearCache(ask = FALSE)
     b <- list(fun = fun)
     a <- list()
@@ -1549,6 +1551,7 @@ test_that("test cache with new approach to match.call", {
 })
 
 test_that("test cache; new approach to match.call, postProcess", {
+  skip_if_not_installed("DBI") # sf needs DBI
   testInitOut <- testInit(c("terra", "sf"), tmpFileExt = c(".tif", ".tif"),
                           opts = list(
                             "rasterTmpDir" = tempdir2(rndstr(1,6)),
@@ -1622,46 +1625,81 @@ test_that("test cache; new approach to match.call, postProcess", {
 
 })
 
-test_that("test cache; SpatRaster attributes", {
-  testInitOut <- testInit(c("terra", "sf"), tmpFileExt = c(".tif", ".tif"),
-                          opts = list(
-                            "rasterTmpDir" = tempdir2(rndstr(1,6)),
-                            "reproducible.inputPaths" = NULL,
-                            "reproducible.overwrite" = TRUE)
-  )
+# test_that("test cache; SpatRaster attributes", {
+#   testInitOut <- testInit(c("terra", "sf"), tmpFileExt = c(".tif", ".tif"),
+#                           opts = list(
+#                             "rasterTmpDir" = tempdir2(rndstr(1,6)),
+#                             "reproducible.inputPaths" = NULL,
+#                             "reproducible.overwrite" = TRUE)
+#   )
+#   on.exit({
+#     testOnExit(testInitOut)
+#   }, add = TRUE)
+#
+#   options("reproducible.cachePath" = tmpdir)
+#   dPath <- file.path(tmpdir, "inputs")
+#
+#   targetFile <- "rasterTest.tif"
+#   url <- "https://github.com/tati-micheletti/host/raw/master/data/rasterTest.tif"
+#
+#   testFun <- function(url, targetFile) {
+#     ras <- prepInputs(url = url,
+#                       targetFile = targetFile)
+#     pixIDs <- which(as.vector(ras[]) == 1)
+#     attr(ras, "pixIDs") <- pixIDs
+#     ras
+#   }
+#
+#   ras <- Cache(testFun,
+#                url = url,
+#                targetFile = targetFile)
+#   expect_true(is.integer(attr(x = ras, "pixIDs")))
+#
+#   ## re-run. attributes still there?
+#   ras <- Cache(testFun,
+#                url = url,
+#                targetFile = targetFile)
+#   expect_true(is.integer(attr(x = ras, "pixIDs")))
+# })
+#
+
+
+test_that("Issue 316 - writeOutputs in a non getwd dir", {
+  testInitOut <- testInit(c("terra"), tmpFileExt = c(".tif", ".tif"))
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
 
-  options("reproducible.cachePath" = tmpdir)
-  dPath <- file.path(tmpdir, "inputs")
+  cPath <- file.path(tmpdir, "cache")
 
-  targetFile <- "rasterTest.tif"
-  url <- "https://github.com/tati-micheletti/host/raw/master/data/rasterTest.tif"
+  withr::local_options("reproducible.cachePath" = cPath,
+                       "reproducible.destinationPath" = tmpdir)
 
-  testFun <- function(url, targetFile) {
-    ras <- prepInputs(url = url,
-                      targetFile = targetFile)
-    pixIDs <- which(as.vector(ras[]) == 1)
-    attr(ras, "pixIDs") <- pixIDs
-    ras
-  }
+  cacheTags <- "test"
+  studyAreaName <- "test"
 
-  ras <- Cache(testFun,
-               url = url,
-               targetFile = targetFile)
-  expect_true(is.integer(attr(x = ras, "pixIDs")))
+  f <- system.file("ex/elev.tif", package="terra")
+  rasterToMatch<- terra::rast(f)
+
+  RTMvals <- as.vector(rasterToMatch[])
+  rasterToMatch[!is.na(RTMvals)] <- 1
+
+  rasterToMatchLarge <- list()
+  for (i in 1:2)
+    rasterToMatchLarge[[i]] <- Cache(writeOutputs, rasterToMatch,
+                                     filename2 = .suffix(file.path(tmpdir, "rasterToMatchLarge.tif"),
+                                                         paste0("_", studyAreaName)), datatype = "INT2U",
+                                     overwrite = TRUE, userTags = c(cacheTags, "rasterToMatchLarge"),
+                                     quick = "filename2",
+                                     omitArgs = c("userTags"))
+
+  expect_equivalent(rasterToMatchLarge[[1]], rasterToMatchLarge[[2]])
 
-  ## re-run. attributes still there?
-  ras <- Cache(testFun,
-               url = url,
-               targetFile = targetFile)
-  expect_true(is.integer(attr(x = ras, "pixIDs")))
 })
 
 
 test_that("test useDBI TRUE <--> FALSE", {
-  testInitOut <- testInit()
+  testInitOut <- testInit(verbose = TRUE)
   on.exit({
     testOnExit(testInitOut)
     useDBI(orig)
@@ -1689,8 +1727,15 @@ test_that("test useDBI TRUE <--> FALSE", {
 
 test_that("lightweight tests for preProcess code coverage", {
   skip_on_cran()
-  out <- testInit(opts = list(reproducible.cachePath = quote(tmpdir)))
-  on.exit(testOnExit(out), add = TRUE)
+  out <- testInit(verbose = TRUE)
+
+  opts <- options(reproducible.cachePath = tmpdir)
+
+  on.exit({
+    testOnExit(out)
+    options(opts)
+  }
+  , add = TRUE)
   expect_error(Cache(), "requires")
   expect_message(Cache(compareRasterFileLength = TRUE, rnorm(1)), regexp = "compareRasterFileLength")
   expect_message(Cache(sideEffect = TRUE, rnorm(1)), regexp = "sideEffect")
