@@ -1,15 +1,12 @@
 test_that("checkPath: normPath consistency", {
   # Use the following here instead of above because it fails on Mac without this.
-  tmpdir <- tempdir2("test_normPath")
-  tmpdir <- normalizePath(tmpdir, winslash = "/", mustWork = FALSE)
+  testInit()
+  # tmpdir <- tempdir2("test_normPath")
+  # tmpdir <- normalizePath(tmpdir, winslash = "/", mustWork = FALSE)
 
-  cwd <- getwd()
-  setwd(tmpdir)
-
-  on.exit({
-    setwd(cwd)
-    unlink(tmpdir, recursive = TRUE)
-  }, add = TRUE) # nolint
+  withr::local_dir(tmpdir)
+  # cwd <- getwd()
+  # setwd(tmpdir)
 
   # don't use checkPath here because we are testing normPath!
 
@@ -26,6 +23,17 @@ test_that("checkPath: normPath consistency", {
   checked <- normPath(paths)
   expect_equal(length(unique(checked)), 1)
 
+
+  # These don't exist ... added May 10, 2023 after discovering that *nix-alikes don't make
+  #   absolute paths with normalizePath when file or dir doesn't exist
+  # Also empty path should return "", not be normalized
+  pathsToCheck <- c("", "hi", "~/Hi", "/home/emcintir/testing", NA, "c:/Eliot")
+  out <- normPath(pathsToCheck)
+  expect_identical(sum(isAbsolutePath(out)), 4L)
+
+  out <- isAbsolutePath(pathsToCheck)
+  expect_identical(c(FALSE, FALSE, TRUE, TRUE, FALSE, TRUE), unname(out))
+
   # extra checks for missing/NA/NULL
   expect_equal(normPath(), character())
   expect_true(all(is.na(normPath(list(NA, NA_character_)))))
@@ -34,9 +42,10 @@ test_that("checkPath: normPath consistency", {
 
 test_that("checkPath: checkPath consistency", {
   testInitOut <- testInit()
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  withr::local_dir(tmpdir)
+  # on.exit({
+  #   testOnExit(testInitOut)
+  # }, add = TRUE)
 
   dir.create("aaa/zzz", recursive = TRUE, showWarnings = FALSE)
   paths <- list("./aaa/zzz",
@@ -51,7 +60,7 @@ test_that("checkPath: checkPath consistency", {
 
   checked <- lapply(paths, checkPath, create = FALSE)
   expect_equal(length(unique(checked)), 1)
-  unlink(tmpdir, recursive = TRUE)
+  # unlink(tmpdir, recursive = TRUE)
 
   # extra checks for missing/NA/NULL
   expect_error(checkPath(), "Invalid path: no path specified.")
